@@ -1,7 +1,7 @@
 # Starfish - Perl-based System for Text-Embedded
 #     Programming and Preprocessing
 #
-# (c) 2001-2012 Vlado Keselj http://web.cs.dal.ca/~vlado
+# (c) 2001-2015 Vlado Keselj http://web.cs.dal.ca/~vlado
 #               and contributing authors
 #
 # See the documentation following the code.  You can also use the
@@ -29,10 +29,10 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS); # Exporter vars
 use vars qw($NAME $ABSTRACT $VERSION);
 $NAME     = 'Starfish';
 $ABSTRACT = 'Perl-based System for Text-Embedded Programming and Preprocessing';
-$VERSION  = '1.17';
+$VERSION  = '1.18';
 
 use vars qw($Revision);
-($Revision = substr(q$Revision: 363 $, 10)) =~ s/\s+$//;
+($Revision = substr(q$Revision: 392 $, 10)) =~ s/\s+$//;
 
 # non-exported package globals
 use vars qw($GlobalREPLACE);
@@ -261,9 +261,14 @@ sub digest {
     
     if ($self->{CurrentLoop} < $self->{Loops}) {
 	++$self->{CurrentLoop};
+	if ($self->{REPLACE}) {             # in replace mode interate with
+	  $self->{data} = $savedcontent;    # original input
+	  goto START;
+	}
 	$self->{data} = $self->{Out};
 	if ($savedcontent ne $self->{Out})
 	{ $self->{LastUpdateTime} = time }
+	putfile 'sfish.debug', $self->{data};
 	goto START;
     }
     
@@ -361,16 +366,16 @@ sub scan {
 
 # eval wrapper for string code
 sub eval1 {
-    my $self = shift;
-    my $code = shift; $code = '' unless defined $code;
-    my $comment = shift;
-    eval("package main; no strict; $code");
-    if ($@) {
-	my ($code1, $linecnt);
-	foreach (split(/\n/, $code))
-	{ ++$linecnt; $code1 .= sprintf("%03d %s\n", $linecnt, $_); }
-	_croak("$comment code error:$@\ncode:\n$code1");
-    }
+  my $self = shift;
+  my $code = shift; $code = '' unless defined $code;
+  my $comment = shift;
+  eval("package main; no strict; $code");
+  if ($@) {
+    my ($code1, $linecnt);
+    foreach (split(/\n/, $code))
+      { ++$linecnt; $code1 .= sprintf("%03d %s\n", $linecnt, $_); }
+    _croak("$comment code error:$@\ncode:\n$code1");
+  }
 }
 
 # The main subroutine for evaluating a snippet of string
@@ -796,7 +801,7 @@ sub setStyle {
 	       {begin => '<!--<?', end => '!>-->', f => \&evaluate },
 	       {begin=>'<?starfish ', end=>'?>', f=>\&evaluate },
         ];
-	$self->addHook(qr/^#.*\n/, 'comment');
+	$self->addHook(qr/^#.*\n/m, 'comment');
 	$self->{CodePreparation} = '';
     }
     elsif ($s eq 'html') {
@@ -874,8 +879,8 @@ sub addHook {
 	}
 	_croak("addHook error:$@") if $@;
     } elsif ($#_ == 1 and ref($_[0]) eq 'Regexp') { #regex hook
-	my $regex=shift; my $replace = shift;
-	if (ref($replace) eq '' && $replace eq 'comment')
+        my $regex=shift; my $replace = shift;
+        if (ref($replace) eq '' && $replace eq 'comment')
 	{ push @Hook, {regex=>$regex, replace=>\&repl_comment} }
 	elsif (ref($replace) eq 'CODE')
 	{ push @Hook, {regex=>$regex, replace=>$replace} }
@@ -1348,6 +1353,18 @@ In Makefile, add lines for updating p_t.java, and generating p.java
         starfish $<
         touch tmp.ind
 
+=head2 Command-line Examples
+
+The following are the reference examples.  For further information, please
+lookup the explanations of the command-line options and arguments.
+
+B<starfish> -mode=0400 -replace -o=I<paper.tex> -mode=0400 I<paper.tex.sfish>
+
+In the above line, Starfish is used on top of a TeX/LaTeX file.  The Starfish
+is separated from the .tex file to keep the source clean.  However, a user in
+this situation may by mistake start editing the paper.tex file, so we set
+the output file mode to 0400 to prevent this accidental editing.
+
 =head2 Macros
 
 I<Note:> This is a quite old part of Starfish and needs a revision.
@@ -1875,7 +1892,7 @@ other comments.
 
 =head1 AUTHORS
 
- 2001-2012 Vlado Keselj http://www.cs.dal.ca/~vlado
+ 2001-2013 Vlado Keselj http://web.cs.dal.ca/~vlado
            and contributing authors:
       2007 Charles Ikeson (overhaul of test.pl)
 
@@ -1883,7 +1900,7 @@ This script is provided "as is" without expressed or implied warranty.
 This is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
-The latest version can be found at F<http://www.cs.dal.ca/~vlado/srcperl/>.
+The latest version can be found at F<http://web.cs.dal.ca/~vlado/srcperl/>.
 
 =head1 SEE ALSO
 
@@ -1942,4 +1959,4 @@ interface.
 =back
 
 =cut
-# $Id: Starfish.pm 363 2012-03-21 14:58:49Z vlado $
+# $Id: Starfish.pm 392 2012-11-12 23:50:45Z vlado $
