@@ -44,6 +44,7 @@ chdir 'tmp' or die;
 &testcase(6, 'out');
 &testcase(8);
 &testcase(9, 'out');
+&testcase(30); # html.sfish to html (16 ok)
 # 10
     copy('../testfiles/9_java.out', '9_java.out');
     #`perl -I. -- starfish -o=10_java.out -e="$slash_hack\$Starfish::HideMacros=1" 9_java.out`;
@@ -152,6 +153,8 @@ sub okfiles {
     my $f1 = shift;
     while (@_) {
 	my $f2 = shift;
+	if (!-f $f1)
+	{ die "file $f1 does not exist (to be compared to tmp/$f2)"	}
 	if (! ok(getfile($f2), getfile($f1)) )
 	{ print STDERR "pwd=".`pwd`."Files: $f1 and $f2\n" }
 
@@ -231,7 +234,8 @@ sub testcase {
     if ($replace) {
 	#`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" -replace -o=$replace $procfile`;
 	starfish_cmd('-e=$ver="testver"', '-replace', "-o=$replace", $procfile);
-	okfiles("../testfiles/$outfile", $replace);
+	#okfiles("../testfiles/$outfile", $replace);
+	comparefiles("../testfiles/$outfile", $replace);
     }
     elsif ($out) {
 	#`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" -o=$out $procfile`;
@@ -244,3 +248,28 @@ sub testcase {
 	okfiles("../testfiles/$outfile", $procfile);
     }
 }
+
+sub comparefiles {
+  my $f1=shift; my $f2=shift;
+  my $fc1=getfile($f1); my $fc2=getfile($f2);
+  if ($fc1 eq $fc2) { ok(1); return; }
+  print STDERR "Difference between $f1 and $f2:\n";
+  while ($fc1 ne '' or $fc2 ne '') {
+    $fc1=~/^.*\n/; my $l1=$&; my $fc1r=$';
+    $fc2=~/^.*\n/; my $l2=$&; my $fc2r=$';
+    if ($l1 eq '' and $l2 eq '') {
+      print STDERR "$f1:$fc1", "$f2:$fc2"; last; }
+    if ($l1 ne $l2) { print STDERR "$f1:$l1", "$f2:$l2" }
+    $fc1=$fc1r; $fc2=$fc2r;
+  }
+  ok(0);
+}
+
+sub getfile($) {
+    my $f = shift;
+    local *F;
+    open(F, "<$f") or die "getfile:cannot open $f:$!";
+    my @r = <F>;
+    close(F);
+    return wantarray ? @r : join ('', @r);
+}
